package com.vendor.burn.serial.workers;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.sun.jna.Native;
import com.vendor.burn.jna.LibBurnByJna;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IFrameSetting;
import com.vendor.burn.serial.workers.FastbootBurnerWorker;
import com.vendor.burn.utilitily.ToolUtils;
import java.io.File;
import java.util.Locale;
import org.eclipse.core.runtime.SubMonitor;

public class CallLibBurnWorker extends FastbootBurnerWorker {
  protected static LibBurnByJna.ProgressCallback progresCallback = (LibBurnByJna.ProgressCallback)new Object();
  
  protected static LibBurnByJna.CancelCallback cancelCallback = (LibBurnByJna.CancelCallback)new Object();
  
  protected static LibBurnByJna.PrintCallback printCallback = (LibBurnByJna.PrintCallback)new Object();
  
  private static final int USB_DEVICES_VID = 4660;
  
  private static final int USB_DEVICES_PID = 22136;
  
  private static final int OPEN_USB_TIMEOUT_MS = 1000;
  
  private static final int I2C_USB_TRANSFORMS_TYPE = 2;
  
  private static final int DEFAULT_PORT = 4444;
  
  private static final int JTAG_FREQUENCE_1M = 1000;
  
  private static final int I2C_CLOCK_SPEED_100K = 100000;
  
  private static final int BOOT_DDR_ADDRESS = 1048576;
  
  private static final String TARGET_FILE = "W5-RISCV" + File.separator + "W5-RISCV-SWD-CORESIGHT";
  
  private static final String INTERFACE_FILE = "cmsis-dap.cfg";
  
  private static long handle = -1L;
  
  private static SubMonitor subMonitor;
  
  private static LibBurnByJna libBurnByJna;
  
  public CallLibBurnWorker(IFrameSetting frameSetting, IBurner burner, SubMonitor subProgressMonitor) {
    super(frameSetting, burner);
    setSubMonitor(subProgressMonitor);
    String osName = System.getProperties().getProperty("os.name");
    if (osName.toLowerCase(Locale.ENGLISH).startsWith("windows")) {
      System.setProperty("jna.encoding", "GBK");
    } else {
      System.setProperty("jna.encoding", "UTF-8");
    } 
    Object object = Native.loadLibrary(ToolUtils.getLibbootromPath(true), LibBurnByJna.class);
    if (object instanceof LibBurnByJna)
      libBurnByJna = (LibBurnByJna)object; 
  }
  
  public static LibBurnByJna getLibBurnByJna() {
    return libBurnByJna;
  }
  
  public static long getHandle() {
    return handle;
  }
  
  public static void setHandle(long handle) {
    com.vendor.burn.serial.workers.CallLibBurnWorker.handle = handle;
  }
  
  public static void setChipType(int chipType) {
    libBurnByJna.SetChipType(chipType);
  }
  
  public static boolean openUsbDevice() {
    long burnResult = libBurnByJna.OpenUsb(4660, 22136, "-1", 2, 1000);
    if (burnResult == 0L)
      return false; 
    setHandle(burnResult);
    libBurnByJna.SetSparkLinkParameters(0, 100000, 0, 0, 0);
    return true;
  }
  
  public static boolean openJtag() {
    String jtagFilePath = ToolUtils.getInstallPath() + "Resources" + ToolUtils.getInstallPath() + "Common" + File.separator + "JTAG" + File.separator;
    long burnResult = libBurnByJna.OpenJtag(0, TARGET_FILE, "cmsis-dap.cfg", null, 1000, 4444, jtagFilePath);
    if (burnResult == 0L)
      return false; 
    setHandle(burnResult);
    return true;
  }
  
  public static boolean downloadBoot(String filePath) {
    int burnResult = libBurnByJna.BootDownload(handle, filePath, 1048576L, 0, null, 0);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean downloadToFlash(String filePath, long address, long length) {
    int burnResult = libBurnByJna.DownloadToFlash(handle, filePath, null, null, address, length, 0, 0);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean eraseFlash(long address, long length) {
    int burnResult = libBurnByJna.EraseFlash(handle, address, length);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean uploadFile(long address, long length, String filePath) {
    int burnResult = libBurnByJna.UploadFile(handle, address, length, filePath);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean reset() {
    int burnResult = libBurnByJna.Reset(handle);
    if (burnResult == 0)
      return false; 
    return true;
  }
  
  public static boolean destroyDevice() {
    int burnResult = libBurnByJna.DestroyDevice(handle);
    if (burnResult == 0)
      return false; 
    setHandle(-1L);
    return true;
  }
  
  public static void setSubMonitor(SubMonitor subMonitor) {
    com.vendor.burn.serial.workers.CallLibBurnWorker.subMonitor = subMonitor;
  }
}
